@@ -36,3 +36,10 @@ DIM = "dimension"
 DIMS = "dimensions"
 ROWDIM = "ROWS"
 COLDIM = "COLUMNS"
+# Range dimensions:
+STARTROW = "startRowIndex"
+ENDROW = "endRowIndex"
+STARTCOL = "startColumnIndex"
+ENDCOL = "endColumnIndex"
+STARTIDX = "startIndex"
+ENDIDX = "endIndex"
