@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import List, Optional, Dict
+from pathlib import Path
 
-from .connection import AuthConfig, DriveConnection, SheetsConnection
+from .connection import AuthConfig, DriveConnection, SheetsConnection, FileUpload
 from .gsheet import GSheet
 
 
@@ -15,6 +16,7 @@ class Folder:
         parents: List[str] | None = None,
         auth_config: AuthConfig | None = None,
         drive_conn: DriveConnection | None = None,
+        sheets_conn: SheetsConnection | None = None,
     ) -> None:
         """
         Stores all the necessary properties of a Google Drive Folder and provides
@@ -31,12 +33,15 @@ class Folder:
                 defaults to None.
             drive_conn (DriveConnection, optional): Optional manually created
                 DriveConnection, defaults to None
+            sheets_conn (SheetsConnection, optional): Optional manually created
+                SheetsConnection, defaults to None.
 
         """
         self._id = folder_id
         self._name = name
         self._parents = parents or []
         self._conn = drive_conn or DriveConnection(auth_config=auth_config)
+        self._sheets_conn = sheets_conn or SheetsConnection(auth_config=self._conn.auth)
 
     @property
     def id(self) -> str:
@@ -90,6 +95,47 @@ class Folder:
             drive_conn=self._conn,
         )
 
+    def create_gsheet(self, gsheet_name: str) -> GSheet:
+        """
+        Creates a new Google Sheet with this Folder as its parent.
+
+        .. note::
+
+            This method will cause a request to be posted to the relevant Google
+            API immediately.
+
+        Args:
+            gsheet_name (str): The desired name of the new Google Sheet.
+
+        Returns:
+            GSheet: The newly created GSheet.
+
+        """
+        new_id = self._conn.create_object(gsheet_name, "sheet", self._id)
+        return GSheet(new_id, gsheet_name, sheets_conn=self._sheets_conn)
+
+    def upload_files(self, *filepaths: Path | str | FileUpload) -> Dict[str, str]:
+        """
+        Uploads files to the folder.
+
+        Args:
+            *filepaths (Path | str | FileUpload): An arbitrary number of Path
+                objects, path strings, or FileUpload objects (if you want to
+                convert the file to a Google Drive format (e.g. Docs, Sheets,
+                etc).
+
+        Returns:
+            Dict[str, str]: The names of the uploaded files and their new ids in
+                Google Drive.
+        """
+        fps: List[FileUpload] = []
+        for fp in filepaths:
+            if isinstance(fp, FileUpload):
+                fp.folder = self.id
+            else:
+                fp = FileUpload(fp, self.id)
+        return self._conn.upload_files(*fps)
+
 
 class Drive:
     """
@@ -209,6 +255,26 @@ class Drive:
             for r in result
         ]
 
+    def upload_files(self, *filepaths: Path | str | FileUpload) -> Dict[str, str]:
+        """
+        Uploads files to the root drive or to a folder.
+
+        .. note::
+
+            This method will cause a request to be posted to the relevant Google
+            API immediately.
+
+        Args:
+            *filepaths (Path | str | FileUpload): An arbitrary number of Path
+                objects, path strings, or FileUpload objects (for more complex
+                cases).
+
+        Returns:
+            Dict[str, str]: The names of the uploaded files and their new ids in
+                Google Drive.
+        """
+        return self._conn.upload_files(*filepaths)
+
     @staticmethod
     def _ensure_parent_id(parent: str | Folder | None = None) -> Optional[str]:
         """
